@@ -17,6 +17,6 @@ int lock_exnb (int fd)
 #else
     r = lockf(fd, 2, 0) ;
 #endif
-  while ((r == -1) && (errno = EINTR)) ;
+  while ((r == -1) && (errno == EINTR)) ;
   return r ;
 }
