@@ -45,6 +45,9 @@
 #include "diuint.h"
 #include "diuintalloc.h"
 #include "diuintbunch.h"
+#include "diuint32.h"
+#include "diuint32alloc.h"
+#include "diuint32bunch.h"
 #include "environ.h"
 #include "shglob.h"
 #include "selfpipe.h"
