@@ -44,6 +44,7 @@ int wait_nohang (int *wstat)
 
 int wait_pid (int *wstat, int pid)
 {
+  int r ;
   {
     register unsigned int i = 0 ;
     for (; i < zombies.len ; i++)
@@ -60,7 +61,7 @@ int wait_pid (int *wstat, int pid)
   for (;;)
   {
     int w ;
-    register int r = wait(&w) ;
+    r = wait(&w) ;
     if (r == pid)
     {
       *wstat = w ;
